@@ -10,9 +10,13 @@ def _to_dict(obj):
     elif hasattr(obj, "__iter__") and not isinstance(obj, str):
         return [_to_dict(v) for v in obj]
     elif hasattr(obj, "__dict__"):
-        data = dict([(key, _to_dict(value))
-                     for key, value in obj.__dict__.items()
-                     if not callable(value) and not key.startswith('_') and value is not None])
+        data = dict(
+            [
+                (key, _to_dict(value))
+                for key, value in obj.__dict__.items()
+                if not callable(value) and not key.startswith("_") and value is not None
+            ]
+        )
         return data
     else:
         return obj
@@ -24,6 +28,7 @@ def version_tuple(v):
 
 def ensure_list(x: Union[Iterable, Any]):
     import collections
+
     if isinstance(x, collections.abc.Iterable):
         return x
     else:
@@ -31,6 +36,7 @@ def ensure_list(x: Union[Iterable, Any]):
 
 
 def to_json_response(obj):
-    """ Following https://stackoverflow.com/a/1118038 """
+    """Following https://stackoverflow.com/a/1118038"""
     from flask import jsonify
+
     return jsonify(_to_dict(obj))
